BBAuthorization enum

The app's authorization to use Bluetooth, exposed via BBManager.authorizationStatus.

Inheritance
Available extensions

Values

unknown → const BBAuthorization

The user hasn't been asked yet. Call BBManager.authorizationRequest (or start a scan) to trigger the system permission prompt.

denied → const BBAuthorization

The user denied permission, or it's restricted by policy (e.g. parental controls). Direct the user to BBManager.authorizationOpenSettings to change it.

authorized → const BBAuthorization

The app is authorized to use Bluetooth.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BBAuthorization>
A constant List of the values in this enum, in order of their declaration.